Help me with this questions so I can review for my exam. | Physics Forums - The Fusion of Science and Community
Description: 1. The problem statement, all variables and given/known data A woman of height 1.7 meters stands directly in front of a convex mirror 2.0 meters away....

- Forums
  - Search Forums
  - Recent Posts
  - Unanswered Threads
- Videos
  - Search Media
  - New Media
- Members
  - Notable Members
  - Current Visitors
  - Recent Activity
  - New Profile Posts
- Insights
- Search

### Log in or Sign up

1. Limited time only! Sign up for a free 30min personal tutor trial with Chegg Tutors
   Dismiss Notice

Dismiss Notice
Join Physics Forums Today!
The friendliest, high quality science and math community on the planet! Everyone who loves science is here!

# Help me with this questions so I can review for my exam.

1. Jun 17, 2008 #1

   ### MoreZitiPlease

   ###

   > 1. The problem statement, all variables and given/known data
   > A woman of height 1.7 meters stands directly in front of a convex mirror 2.0 meters away. The mirror has a radius of curvature, R=-50cm. Find the location and size of a woman's image using the ray diagram and mirror/lens equation.
   > ----------
   > 2. The speed of light in a material is 2.50x10^8 meters per second. What is the index of refraction of the material?
   > 2. Relevant equations
   > 3. The attempt at a solution
   > 1. di=22.22
   > 2. Dont know

   MoreZitiPlease, Jun 17, 2008
2. Phys.org - latest science and technology news stories on Phys.org
   - • What does a bear do in the Alaska woods? Disperse seeds
   - • Personalized curriculum captures students' imagination, interest
   - • Asteroid 'time capsules' may help explain how life started on Earth
3. Jun 17, 2008 #2

   ### lzkelley

   ###

   > why dont you look in your book for "index of refraction" and see what it says?

   lzkelley, Jun 17, 2008
4. Jun 17, 2008 #3

   ### gendou2

   ###

   > This website has the information you need:
   > http://www.sasked.gov.sk.ca/docs/physics/u3a22phy.html [Broken]

   Last edited by a moderator: May 3, 2017
   gendou2, Jun 17, 2008
5. Jun 17, 2008 #4

   ### MoreZitiPlease

   ###

   > Is number 1 right?

   MoreZitiPlease, Jun 17, 2008
6. Jun 17, 2008 #5

   ### MoreZitiPlease

   ###

   > I got 1.2 for 2

   MoreZitiPlease, Jun 17, 2008

Show Ignored Content
Know someone interested in this topic? Share this thread via Reddit, Google+, Twitter, or Facebook
The Birth of a Textbook
Mathematical Quantum Field Theory – Gauge Fixing
A Journey Into the Cosmos – FLRW Metric and The Friedmann Equation
Mathematical Quantum Field Theory – Observables
Interview with Mathematician and Physicist Arnold Neumaier
The Homopolar Generator: An Analytical Example
The Schwarzschild Metric: Part 1, GPS Satellites
A Journey Into the Cosmos – The Friedmann Equation
Mathematical Quantum Field Theory – Reduced Phase Space
Mathematical Quantum Field Theory – Free Quantum Fields
Make Units Work for You

  Similar Discussions: Help me with this questions so I can review for my exam.

1. ### Need help with an exam review question (Replies: 3)

2. ### SO I have an Exam Tomorrow. Review Questions! (Replies: 3)

3. ### Help review for exam (last question) (Replies: 5)

4. ### Reviewing for my exam (Newton question) (Replies: 1)

5. ### Pls can someone help me to solve this question, am practicing for my exams. (Replies: 7)

Loading...

- Log in with Facebook
- Log in with Twitter

Your name or email address:

Do you already have an account?
  - No, create an account now.
  - Yes, my password is:
  - Forgot your password?

  Stay logged in